@@ -1,7 +1,7 @@
 package App::BencherUtils;
 
 our $DATE = '2017-07-13'; # DATE
-our $VERSION = '0.21'; # VERSION
+our $VERSION = '0.22'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -622,6 +622,9 @@ _
         with_process_size => {
             schema => 'bool*',
         },
+        precision => {
+            schema => 'float*',
+        },
     },
 
 };
@@ -645,6 +648,7 @@ sub bencher_code {
         scenario => $scenario,
         code_startup => $args{startup},
         with_process_size => $args{with_process_size},
+        (precision => $args{precision}) x !!(defined $args{precision}),
     );
     return $res unless $res->[0] == 200;
 
@@ -670,7 +674,7 @@ App::BencherUtils - Utilities related to bencher
 
 =head1 VERSION
 
-This document describes version 0.21 of App::BencherUtils (from Perl distribution App-BencherUtils), released on 2017-07-13.
+This document describes version 0.22 of App::BencherUtils (from Perl distribution App-BencherUtils), released on 2017-07-13.
 
 =head1 SYNOPSIS
 
@@ -728,6 +732,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<codes>* => I<array[str]>
 
+=item * B<precision> => I<float>
+
 =item * B<startup> => I<bool> (default: 0)
 
 Use code_startup mode instead of normal benchmark.
